.. include:: README_pypi.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   quickstart
   edge_cases
   processing
   create_config
   sweep
   api/main
   contribute
   license
